'use strict';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpKernel = void 0;
const filesystem_1 = __importDefault(require("@supercharge/filesystem"));
const http_1 = require("@supercharge/http");
const bootstrappers_1 = require("../bootstrappers");
class HttpKernel {
    /**
     * Create a new HTTP kernel instance.
     *
     * @param {Application} app
     */
    constructor(app) {
        this.meta = { app };
        this.server = new http_1.Server(this);
    }
    /**
     * Creates a new HTTP kernel instance for the given `app`.
     *
     * @param {Application} app
     */
    static for(app) {
        return new this(app);
    }
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     *
     * @returns {MiddlewareCtor[]}
     */
    middleware() {
        return [];
    }
    /**
     * Returns the application’s global middleware stack. Every middleware
     * listed here runs on every request to the application.
     *
     * @returns {MiddlewareCtor[]}
     */
    routeMiddleware() {
        return {};
    }
    /**
     * Returns the path to the HTTP controllers.
     *
     * @returns {String}
     */
    controllersLocation() {
        return this.app().resolveFromBasePath('app/http/controllers');
    }
    /**
     * Returns the app instance.
     */
    app() {
        return this.meta.app;
    }
    /**
     * Start the HTTP instance listening for incoming requests.
     *
     * @returns {Promise}
     */
    async startServer() {
        await this.bootstrap();
        await this.listen();
    }
    /**
     * Bootstrap the application by loading environment variables, load the
     * configuration, register service providers into the IoC container
     * and ultimately boot the registered providers.
     */
    async bootstrap() {
        await this.app().bootstrapWith(this.bootstrappers());
        await this.server.bootstrap();
    }
    /**
     * Returns the list of application bootstrappers.
     */
    bootstrappers() {
        return [
            bootstrappers_1.HandleExceptions,
            bootstrappers_1.LoadEnvironmentVariables,
            bootstrappers_1.LoadConfiguration,
            bootstrappers_1.RegisterServiceProviders,
            bootstrappers_1.BootServiceProviders
        ];
    }
    /**
     * Returns an array of file paths to all controllers.
     *
     * @returns {String[]}
     */
    async controllerPaths() {
        return await filesystem_1.default.allFiles(this.controllersLocation());
    }
    /**
     * Start the HTTP server.
     */
    async listen() {
        await this.server.start();
    }
}
exports.HttpKernel = HttpKernel;
